Crate pallet_staking_async_ah_client

Crate pallet_staking_async_ah_client 

The client for AssetHub, intended to be used in the relay chain.

The counter-part for this pallet is pallet-staking-async-rc-client on AssetHub.

This documentation is divided into the following sections:

  1. Incoming messages: the messages that we receive from the relay chian.
  2. Outgoing messages: the messaged that we sent to the relay chain.
  3. Local interfaces: the interfaces that we expose to other pallets in the runtime.

Incoming Messages

All incoming messages are handled via Call. They are all gated to be dispatched only by Config::AssetHubOrigin. The only one is:

Outgoing Messages

All outgoing messages are handled by a single trait pallet_staking_async_rc_client::SendToAssetHub. They match the incoming messages of the rc-client pallet.

Local Interfaces:

Living on the relay chain, this pallet must:

Future Plans

  • Governance functions to force set validators.

Re-exports

pub use pallet::*;

Modules

pallet
The pallet module in each FRAME pallet hosts the most important items needed to construct this pallet.

Macros

log

Structs

DefaultExposureOf
See pallet_staking::DefaultExposureOf. This type is the same, except it is duplicated here so that an rc-runtime can use it after pallet-staking is fully removed as a dependency.

Enums

OperatingMode
Represents the operating mode of the pallet.

Traits

SendToAssetHub
The interface to communicate to asset hub.
SessionInterface
Re-export SessionInterface from pallet_session.

Type Aliases

BalanceOf
The balance type seen from this pallet’s PoV.
OffenceDetailsOf
Type alias for offence details